==> dasu_1.0.jar: edu/northwestern/dasu/drools/FactSpeedTestResult.java <==
package edu.northwestern.dasu.drools;

import edu.northwestern.dasu.measurement.TestType;

public class FactSpeedTestResult extends FactTestResult {
	
	public long testTime;
	public int downloadSpeed = -1;
	public int uploadSpeed = -1;
	public boolean encryption = false;
	public boolean success = true;
	public String lastError;

	public FactSpeedTestResult(TestType testType) {
		super(testType);
	}
	
	public FactSpeedTestResult(TestType testType, long testTime, int downloadSpeed,
			int uploadSpeed, boolean hadError, String lastError, boolean encryption) {
		super(testType);
		this.testTime = testTime;
		this.downloadSpeed = downloadSpeed;
		this.uploadSpeed = uploadSpeed;
		this.success = !hadError;
		this.lastError = lastError;
		this.encryption = encryption;
	}

	public long getTestTime() {
		return testTime;
	}

	public int getDownloadSpeed() {
		return downloadSpeed;
	}

	public int getUploadSpeed() {
		return uploadSpeed;
	}

	public boolean isEncryption() {
		return encryption;
	}

	public boolean isSuccess() {
		return success;
	}

	public String getLastError() {
		return lastError;
	}

	public void setTestTime(long testTime) {
		this.testTime = testTime;
	}

	public void setDownloadSpeed(int downloadSpeed) {
		this.downloadSpeed = downloadSpeed;
	}

	public void setUploadSpeed(int uploadSpeed) {
		this.uploadSpeed = uploadSpeed;
	}

	public void setEncryption(boolean encryption) {
		this.encryption = encryption;
	}

	public void setSuccess(boolean success) {
		this.success = success;
	}

	public void setLastError(String lastError) {
		this.lastError = lastError;
	}

	
}

==> dasu_3.02.jar: edu/northwestern/dasu/drools/FactSpeedTestResult.java <==
package edu.northwestern.dasu.drools;

import edu.northwestern.dasu.measurement.TestType;

public class FactSpeedTestResult extends FactTestResult {
	
	public long testTime;
	public int downloadSpeed = -1;
	public int uploadSpeed = -1;
	public boolean encryption = false;
	public boolean success = true;
	public String lastError;
	public int downloadSpeedNetstat = -1; /*kBps*/
	public int uploadSpeedNetstat = -1; /*kBps*/

	public FactSpeedTestResult(TestType testType) {
		super(testType);
	}
	
	public FactSpeedTestResult(TestType testType, long testTime, int downloadSpeed,
			int uploadSpeed, boolean hadError, String lastError, boolean encryption,
			int downloadSpeedNetstat, int uploadSpeedNetstat) {
		
		super(testType);
		this.testTime = testTime;
		this.downloadSpeed = downloadSpeed;
		this.uploadSpeed = uploadSpeed;
		this.success = !hadError;
		this.lastError = lastError;
		this.encryption = encryption;
		this.downloadSpeedNetstat = downloadSpeedNetstat;
		this.uploadSpeedNetstat = uploadSpeedNetstat;
	}

	public long getTestTime() {
		return testTime;
	}

	public int getDownloadSpeed() {
		return downloadSpeed;
	}

	public int getUploadSpeed() {
		return uploadSpeed;
	}

	public boolean isEncryption() {
		return encryption;
	}

	public boolean isSuccess() {
		return success;
	}

	public String getLastError() {
		return lastError;
	}

	public void setTestTime(long testTime) {
		this.testTime = testTime;
	}

	public void setDownloadSpeed(int downloadSpeed) {
		this.downloadSpeed = downloadSpeed;
	}

	public void setUploadSpeed(int uploadSpeed) {
		this.uploadSpeed = uploadSpeed;
	}

	public void setEncryption(boolean encryption) {
		this.encryption = encryption;
	}

	public void setSuccess(boolean success) {
		this.success = success;
	}

	public void setLastError(String lastError) {
		this.lastError = lastError;
	}

	public int getDownloadSpeedNetstat() {
		return downloadSpeedNetstat;
	}

	public int getUploadSpeedNetstat() {
		return uploadSpeedNetstat;
	}

	public void setDownloadSpeedNetstat(int downloadSpeedNetstat) {
		this.downloadSpeedNetstat = downloadSpeedNetstat;
	}

	public void setUploadSpeedNetstat(int uploadSpeedNetstat) {
		this.uploadSpeedNetstat = uploadSpeedNetstat;
	}

	
}
